# streamlit-custom-component

Streamlit component that allows you to do build nivo heatmap chart

## Installation instructions

```sh
pip install streamlit-heatmap-chart
```

## Usage instructions

```python
import streamlit as st

from streamlit_heatmap import HeatMap_chart

value = HeatMap_chart(
    data,styles,heatmapLayout
)

```